@@ -12,6 +12,6 @@ test_that("cf_query", {
   expect_is(tt$`Date(local)`, "POSIXct")
   expect_is(tt$`Amount(MJ/m2)`, "numeric")
   expect_is(tt$`Period(Hrs)`, "integer")
-  expect_is(tt$Type, "factor")
-  expect_is(tt$Freq, "factor")
+  expect_is(tt$Type, "character")
+  expect_is(tt$Freq, "character")
 })
